<?php

/**
 */
class Plugin extends TangoDunePlugin
{

    public function handle_user_input(&$input, &$plugin_cookies)
    {
        Cookie::init($plugin_cookies);

        // Calling for it, is very impotant for auto upgrading.
        $result = parent::handle_user_input($input, $plugin_cookies);

        hd_print($result);
        
        if ($result) return $result;


        return Screen::call_input($input);
    }

    public function get_folder_view($media_url, &$plugin_cookies)
    {
        Cookie::init($plugin_cookies);
        return Screen::view($media_url);
    }

    public function get_regular_folder_items($media_url, $from_ndx, &$plugin_cookies)
    {
        Cookie::init($plugin_cookies);
        return Screen::viewRegular($media_url, $from_ndx);
    }

    /**
     *
     * @param type $url 
     */
    function choose_quality($url)
    {
        $result = '';

        $video_quality = Cookie::get('video_quality', '7777'); // Get high quality, if not set.

        foreach (array('720', '480', '360', '240') as $v)
        {
            if ($v > $video_quality) continue;

            $handle = curl_init($url . '.' . $v . '.mp4');
            curl_setopt($handle, CURLOPT_RETURNTRANSFER, TRUE);
            curl_setopt($handle, CURLOPT_TIMEOUT, 1); // 1 sec timelimit.

            $response = curl_exec($handle);

            $httpCode = curl_getinfo($handle, CURLINFO_HTTP_CODE);
            if ($httpCode == 404)
            {
                hd_print("quality 404 = " . $url . '.' . $v . '.mp4');
            } else
            {
                $result = $url . '.' . $v . '.mp4';

                break;
            }

            curl_close($handle);
        }

        return $result;
    }

    /**
     *
     * @param type $media_url
     * @param type $plugin_cookies
     * @return type 
     */
    public function get_vod_info($media_url, &$plugin_cookies)
    {
        preg_match_all('/(.*)->.*?\/(.*)/', $media_url, $matches);

        if (isset($matches[1][0]))
        {
            $movie_class = new $matches[1][0];
            
            $playback_url_is_stream_url = true;
            
            $movie = $movie_class->getVideoInfo($matches[2][0]);

            
            try
            {
                $frame = file_get_contents($movie['file']);
            } catch (Exception $e) {}

            $regexp = "{video_host = '(.*?)'.*?video_uid = '(.*?)'.*?video_vtag = '(.*?)'}si";
            preg_match_all($regexp, $frame, $frame_m);

            if (isset($frame_m[1][0]))
            {
                $linkToVideo = $frame_m[1][0] . '/u' . $frame_m[2][0] . '/video/' . $frame_m[3][0];
            }

            $title = $movie['title'];
            $poster = $movie['image'];
            $description = $movie['description'];
            
            $video_url = Url::prepareVideoUrl($this->choose_quality($linkToVideo));
        } 
        else // serials
        {
            $movie = json_decode(urldecode($media_url));

            $title = $movie->title . ' [' . $movie->seria_name . ']';
            $description = $movie->description;
            $poster = $movie->poster;
            $linkToVideo = $movie->file;
            
            $playback_url_is_stream_url = false;
            
            
            $video_url = Url::prepareVideoUrl($linkToVideo);
        }


        $buffer_ms = Cookie::get('buffer_ms', 0);

        return array
            (
            PluginVodInfo::name => $title,
            PluginVodInfo::description => $description,
            PluginVodInfo::poster_url => $poster,
            PluginVodInfo::initial_series_ndx => 0,
            PluginVodInfo::series => array
                (
                array
                    (
                    PluginVodSeriesInfo::name => 'Video',
                    PluginVodSeriesInfo::playback_url => $video_url,
                    PluginVodSeriesInfo::playback_url_is_stream_url => $playback_url_is_stream_url,
                )
            ),
            PluginVodInfo::buffering_ms => ($buffer_ms * 1000),
            PluginVodInfo::ip_address_required => TRUE,
            PluginVodInfo::valid_time_required => FALSE,
        );
    }

    /**
     *
     * @param type $media_url
     * @param type $plugin_cookies
     * @return type 
     */
    public function get_vod_stream_url($media_url, &$plugin_cookies)
    {
        $frame_url = 'http://' . substr($media_url, strlen('http://mp4://'));

        try
        {
            $frame = file_get_contents($frame_url);
        } catch (Exception $e) {}
        
        $regexp = "{video_host = '(.*?)'.*?video_uid = '(.*?)'.*?video_vtag = '(.*?)'}si";
        preg_match_all($regexp, $frame, $frame_m);

        if (isset($frame_m[1][0]))
        {
            $s_url = $frame_m[1][0] . '/u' . $frame_m[2][0] . '/video/' . $frame_m[3][0];
        }

        return Url::prepareVideoUrl($this->choose_quality($s_url));
    }

    /**
     * Changing view.
     * @param type $media_url
     * @param type $plugin_cookies
     * @return type 
     */
    function get_next_folder_view($media_url, &$plugin_cookies)
    {
        Cookie::init($plugin_cookies);
        preg_match_all('/(.*)->.*?\/(.*)/', $media_url, $matches);

        $node = empty($matches[2][0]) ? 'narkomsu.start_page' : $matches[2][0] . '.childs';

        //  kind of configuration.
        $node = str_replace('start_page.catalog.childs', 'categories', $node);

        $style = Cookie::get('current_list_style', 'image');

        if ($style != 'image')
        {
            $items = Screen::build_category($node);
        } else
        {
            $items = Screen::build_category_with_image($node);
        }

        if (count($items) > 0)
        {
            if ($style != 'image')
            {
                Cookie::set('current_list_style', 'image');
            } else
            {
                Cookie::set('current_list_style', 'text');
            }
        } else
        {
            $style = Cookie::get('current_list_video_style', '0');

            $style = is_numeric($style) && $style < 2 ? ++$style : 0;

            Cookie::set('current_list_video_style', $style);
        }

        return $this->get_folder_view($media_url, $plugin_cookies);
    }

}

?>
